/**********************
* WARNING
* Running this code sample will cost you Browshot credits
***********************/
'use strict';

const browshot = require('browshot');

var client = new browshot('my_api_key');

var interval;

// the call to screenshot/create sends the same response as screenshot/info
// so screenshot/create and screenshot/info can be interchanged as long as the cache value is long enough
client.screenshotCreate(
  // additional details
	{url: 'https://browshot.com/', instance_id: 24, size: 'page', details: 3, screen_width: 1280, screen_height: 1024}, 
	function(screenshot) {
		// If the screenshot is already in cache, it could be finished already. Otherwise, wait longer
		if (screenshot.status == 'error') {
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			screenshotFinished(screenshot);
		}
		else {
			interval = setInterval(checkScreenshot, 1000 * 10, screenshot.id);
		}
	}
);

function checkScreenshot(id) {
	client.screenshotInfo(id, { details: 3 }, function(screenshot) {
		if (screenshot.status == 'error') {
			clearInterval(interval);
			
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			clearInterval(interval);
			
			screenshotFinished(screenshot);
		}
		else {
			console.log(`Waiting for screenshot #${screenshot.id} to finish...`);
		}
	});
}

function screenshotFinished(screenshot) {
	// Did the page load (200 OK) or was mnissing (404 Not Found) or some error (40X, 50X);
	if (screenshot.response_code != 200) {
		console.log(`The page may not have be reached, HTTP response code was: ${screenshot.response_code}`);
	}
	
	// Was it an HTML page, PDF or image?
	if (screenshot.content_type != 'text/html') {
    console.log(`The page is not HTML, it is ${screenshot.content_type}`);
  }
  
  // with details = 3, you can check what asserts were loaded on the page: images, javascript, frames, etc.
  if (screenshot.hasOwnProperty('images')) {
		console.log(`There are ${screenshot.images.length} images on this page:`);
		
		for(var i in screenshot.images) {
			console.log("\t" + screenshot.images[i]);
		}
  }
}